Modules
Structs
- Args
- Artifact
Loader - A loader for artifacts associated with a specific experiment in Burn Central.
- Cancel
Token - A token that can be used to cancel an ongoing inference job.
- Emit
Error - Error returned when emitting an item fails. The item of type T is returned to allow for potential retries.
- Execution
Context - The execution context for a routine, containing the necessary information to run it.
- Executor
- An executor that manages the execution of routines for different targets.
- Executor
Builder - A builder for creating an
Executorinstance with registered routines. - In
- Inference
- Inference instance wrapping a single model and a handler routine.
- Inference
Builder - Entry point builder for an
Inferenceinstance. - Inference
Job - Concrete job containing fully specified execution parameters passed to the runtime.
- Inference
JobBuilder - Internal job builder accumulating input + devices + optional state before conversion to an executable job.
- JobHandle
- Handle to a running inference job thread.
- Loaded
Inference Builder - Builder returned after a model has been loaded or supplied ready for registering a handler.
- Model
- Model
Accessor - Cloneable handle used to execute closures against the model on its host thread.
- Multi
Device - Out
- OutStream
- Lightweight cloneable wrapper exposing an
Emitterimplementation to user handlers. - State
- State
Missing - Marker type indicating the job state has not been supplied.
- State
Provided - Marker type indicating the job state has been supplied.
- Strapped
Inference JobBuilder - Builder returned by
Inference::inferallowing configuration (devices, state) before executing the job viaStrappedInferenceJobBuilder::runor spawning viaStrappedInferenceJobBuilder::spawn.
Enums
- Inference
Error - Errors that can occur during inference job execution.
- Runtime
Error
Traits
- Emitter
- The sending side of an output stream for inference outputs.
- Init
- Trait for models that can be initialized from user-defined arguments.
- Into
Routine - Routine