ArtifactLoader

Struct ArtifactLoader 

pub struct ArtifactLoader<T: BundleDecode> { /* private fields */ }
Artifact loader for loading artifacts from Burn Central. It allow to fecth for instance other experiment endpoint to be able to restart from a certain point your experiment.

You can build it yourself by using the ArtifactLoader::new function with your namespace (in slug format (e.g. “my-team”)), project name and a burn_central_core::BurnCentral. However, it is also possible to request it directly in your routine by using declaring the param like so:

#[derive(Deserialize, Serialize, Default)]
pub struct LaunchArgs {
    pub experiment_num: Option<i32>,
}

#[register(training, name = "mnist")]
pub fn training<B: AutodiffBackend>(
    config: Args<LaunchArgs>,
    MultiDevice(devices): MultiDevice<B>,
    loader: ArtifactLoader<ModelArtifact<B>>,
) -> Result<Model<ModelArtifact<B::InnerBackend>>, String> {
    // Load a pretrained model if an experiment number is provided.
    if let Some(experiment_num) = config.experiment_num {
        let pretrained_model = loader
            .load(experiment_num, "train_artifacts")
            .expect("To be able to fetch artifacts");
    }
}

As you can see in the example above, you can use the loader to dynamically request experiment artifacts when requested through your routine configuration.

Implementations

Source

impl<T: BundleDecode> ArtifactLoader<T>

pub fn new(namespace: String, project_name: String, client: BurnCentral) -> Self

pub fn load_with( &self, experiment_num: i32, name: impl AsRef<str>, settings: &T::Settings, ) -> Result<T, ArtifactError>

Load an artifact by name with specific settings.

pub fn load( &self, experiment_num: i32, name: impl AsRef<str>, ) -> Result<T, ArtifactError>

Load an artifact by name with default settings.