pub struct Inference<B: Backend, M, I, O, S = ()> {
pub id: String,
/* private fields */
}Expand description
Inference instance wrapping a single model and a handler routine.
An Inference can create multiple jobs (sequentially or concurrently) without re-loading the model.
Fields
id: StringImplementations
Sourceimpl<B, M, I, O, S> Inference<B, M, I, O, S>
impl<B, M, I, O, S> Inference<B, M, I, O, S>
Sourcepub fn infer(
&self,
input: I::Inner<'static>,
) -> StrappedInferenceJobBuilder<'_, B, M, I, O, S, StateMissing>
pub fn infer( &self, input: I::Inner<'static>, ) -> StrappedInferenceJobBuilder<'_, B, M, I, O, S, StateMissing>
Start building an inference job for the given input payload.
Sourcepub fn run(&self, job: InferenceJob<B, I, S>) -> Result<Vec<O>, InferenceError>
pub fn run(&self, job: InferenceJob<B, I, S>) -> Result<Vec<O>, InferenceError>
Execute the provided job synchronously and collect all emitted outputs.
Sourcepub fn spawn(&self, job: InferenceJob<B, I, S>) -> JobHandle<O>where
<I as RoutineInput>::Inner<'static>: Send,
pub fn spawn(&self, job: InferenceJob<B, I, S>) -> JobHandle<O>where
<I as RoutineInput>::Inner<'static>: Send,
Spawn the job on a background thread returning a JobHandle. Outputs can be read from the handle’s stream.
Sourcepub fn into_model(self) -> M
pub fn into_model(self) -> M
Consume the inference instance and retrieve ownership of the underlying model.