pub struct InferenceJob<B: Backend, I: RoutineInput, S> { /* private fields */ }Expand description
Concrete job containing fully specified execution parameters passed to the runtime.
Implementations
Sourceimpl<B, I, S> InferenceJob<B, I, S>
impl<B, I, S> InferenceJob<B, I, S>
Sourcepub fn builder(
input: <I as RoutineInput>::Inner<'static>,
) -> InferenceJobBuilder<B, I, S, StateMissing>
pub fn builder( input: <I as RoutineInput>::Inner<'static>, ) -> InferenceJobBuilder<B, I, S, StateMissing>
Create a new builder for an inference job for the given input payload.