pub struct JobHandle<S> {
pub id: String,
pub stream: Receiver<S>,
/* private fields */
}Expand description
Handle to a running inference job thread.
Provides access to the output stream (stream) plus cancellation (cancel) and
a join method to retrieve the final result (or error) once the handler terminates.
Fields
id: Stringstream: Receiver<S>Implementations
Sourceimpl<S> JobHandle<S>
impl<S> JobHandle<S>
pub fn new( id: String, stream: Receiver<S>, cancel: CancelToken, join: JoinHandle<Result<(), InferenceError>>, ) -> Self
Sourcepub fn cancel(&self)
pub fn cancel(&self)
Cancel the running job. This will signal the job to stop processing as soon as possible.
Note that this does not immediately kill the thread, but rather requests it to stop.
The inference function has to use the CancelToken to check for cancellation.
Sourcepub fn join(self) -> Result<(), InferenceError>
pub fn join(self) -> Result<(), InferenceError>
Wait for the job to finish and return the result.