pub struct LoadedInferenceBuilder<B: Backend, M> { /* private fields */ }Expand description
Builder returned after a model has been loaded or supplied ready for registering a handler.
Implementations
Sourceimpl<B, M> LoadedInferenceBuilder<B, M>
impl<B, M> LoadedInferenceBuilder<B, M>
Sourcepub fn build<F, I, O, RO, Marker, S>(
self,
handler: F,
) -> Inference<B, M, I, O, S>where
F: IntoRoutine<InferenceContext<B, M, O, S>, I, RO, Marker>,
I: RoutineInput + 'static,
O: Send + 'static,
S: Send + Sync + 'static,
RO: InferenceOutput<B, M, O, S> + Sync + 'static,
pub fn build<F, I, O, RO, Marker, S>(
self,
handler: F,
) -> Inference<B, M, I, O, S>where
F: IntoRoutine<InferenceContext<B, M, O, S>, I, RO, Marker>,
I: RoutineInput + 'static,
O: Send + 'static,
S: Send + Sync + 'static,
RO: InferenceOutput<B, M, O, S> + Sync + 'static,
Finalize the construction of an Inference by supplying a handler routine implementation.