ExperimentArgs

Trait ExperimentArgs 

pub trait ExperimentArgs:
    Serialize
    + for<'de> Deserialize<'de>
    + Default { }
Trait for experiments arguments. It specify that the type must be serializable, deserializable and implement default. The reason it must implement default is that when you override a value it will only override the value you provide, the rest will be filled with the default value.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl<T> ExperimentArgs for T
where T: Serialize + for<'de> Deserialize<'de> + Default,